nvm package
===========

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   nvm.aux_log
   nvm.aux_pandas
   nvm.aux_str
   nvm.aux_sys

Submodules
----------

nvm.nvm module
--------------

.. automodule:: nvm.nvm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: nvm
   :members:
   :undoc-members:
   :show-inheritance:
